@@ -1,8 +1,10 @@
 #!/usr/bin/env python3
 
-import click
 import json
 from pathlib import Path
+import sys
+
+import click
 
 import resume_pycli
 import resume_pycli.utils as u
@@ -11,7 +13,6 @@ import resume_pycli.utils as u
 @click.group()
 def cli() -> None:
     """CLI tool to easily setup a new resume."""
-    pass
 
 
 @click.command()
@@ -47,20 +48,20 @@ def validate(resume, schema) -> None:
     err = u.validate(resume_file, schema_file)
     if err:
         click.echo(err, err=True)
-        exit(1)
-
+        sys.exit(1)
 
 
 @click.command()
 @click.option("--port", default=4000, help="Serve on a custom port.")
-@click.option("--dir", default="public", help="Serve a custom directory.")
+@click.option("--path", default="public", help="Serve a custom directory.")
 @click.option("--silent", is_flag=True, help="Do not open web browser.")
-def serve(port, dir, silent) -> None:
+def serve(port, path, silent) -> None:
     """Serve resume."""
     click.echo(f"Serving on http://localhost:{port}/ ...")
     if not silent:
         click.launch(f"http://localhost:{port}/")
-    u.serve("localhost", port, dir)
+    u.serve("localhost", port, path)
+
 
 @click.command()
 @click.option(
@@ -71,17 +72,24 @@ def serve(port, dir, silent) -> None:
 )
 @click.option("--theme", help="Specify the to used to build the resume.")
 @click.option("--pdf", is_flag=True, help="Export to PDF only.")
+@click.option(
+    "--pdf-options",
+    help='Pass options as quoted Python dict to wkhtmltopdf (ex: \'{"page-size": "A4"}\').',
+    default="{}",
+    callback=u.cb_pdf_options,
+)
 @click.option("--html", is_flag=True, help="Export to HTML only.")
-def export(resume, theme, pdf, html) -> None:
+@click.option("--output", help="Specify the output directory.", default="public")
+def export(resume, theme, pdf, pdf_options, html, output) -> None:
     """Export to HTML and PDF."""
     resume_file = json.load(resume)
     if not theme:
         theme = resume_file["meta"].get("theme", "base")
     Path("public").mkdir(parents=True, exist_ok=True)
     if html or not pdf:
-        u.export_html(resume_file, theme)
+        u.export_html(resume_file, theme, output)
     if pdf or not html:
-        u.export_pdf(resume_file, theme)
+        u.export_pdf(resume_file, theme, output, pdf_options)
 
 
 @click.command()
